const path = require('path'),
    koa = require('koa'),
    serve	= require('koa-static'),
    metalsmith = require('metalsmith'),
    markdown = require('metalsmith-markdown'),
    layouts = require('metalsmith-layouts'),
    collections	= require('metalsmith-collections'),
    permalinks = require('metalsmith-permalinks'),
    beautify = require('metalsmith-beautify'),
    feed = require('metalsmith-feed'),
    moment = require('moment'),
    app = koa();

const site = {
    author: 'Ev Bogue',
    photo: 'evbogue-badass.jpg',
    title: 'Metalwork',
    url: 'http://evbogue.com/metalwork/'
};

const blog = {
    pattern: './*.md',
    reverse: true,
    sortBy: 'date'
};

const pattern = ':collections:title',
    collection = 'blog',
    engine = 'jade',
    dest = path.join(__dirname, 'build'),
    port = '3000';

metalsmith(__dirname)
    .metadata({site})
    .use(markdown())
    .use(collections({blog}))
    .use(permalinks({pattern}))
    .use(feed({collection}))
    .use(layouts({engine, moment}))
    .use(beautify())
    .destination(dest)
    .build(err => {
      if (err) throw err;
      console.log('Metalwork is built');
    });

app.use(serve(dest));
app.listen(port);

console.log(`Metalwork is listening at http://localhost:${port}/`);

